@@ -103,7 +103,8 @@ class pygtkeditor_window(hildon.Window):
       self.recent_opened_submenu.remove(child)
     #Recently opened sub menuecently opened sub menu
     for opened_file in self.last_opened_files:
-      item = gtk.MenuItem (opened_file)
+      item = gtk.MenuItem (opened_file,use_underline=False)
+#      item.remove_mnemonic_label()
       item.connect ("activate", self.cb_tb_open_recent,opened_file)
       item.show ()
       self.recent_opened_submenu.append (item)    
@@ -220,7 +221,7 @@ class pygtkeditor_window(hildon.Window):
     self.recent_opened_submenu = gtk.Menu()
     recent_opened_menuitem.set_submenu (self.recent_opened_submenu)
     for opened_file in self.last_opened_files:
-      item = gtk.MenuItem (opened_file)
+      item = gtk.MenuItem (opened_file,use_underline=False)
       item.connect ("activate", self.cb_tb_open_recent,opened_file)
       item.show ()
       self.recent_opened_submenu.append (item)    
@@ -292,16 +293,16 @@ class pygtkeditor_window(hildon.Window):
     new_menuitem.connect ("activate", self.cb_tb_dup_line)
     new_menuitem.show ()
     editmenu.append (new_menuitem)
-    
+
     item = gtk.SeparatorMenuItem ()
     item.show ()
     editmenu.append (item)
-    
+
     new_menuitem = gtk.MenuItem ("Replace tab by space")
     new_menuitem.connect ("activate", self.cb_tb_rep_tabs)
     new_menuitem.show ()
     editmenu.append (new_menuitem)    
-    
+
     item = gtk.SeparatorMenuItem ()
     item.show ()
     editmenu.append (item)    
@@ -450,14 +451,14 @@ class pygtkeditor_window(hildon.Window):
   def cb_tb_dup_line(self,widget):
     id_page = self.notebook.get_current_page()
     self.textview_list[id_page].duplicate_line() 
-    
+
   ###############################################################################
   # @brief Replace tabs by space
   ###############################################################################
   def cb_tb_rep_tabs(self,widget):
     id_page = self.notebook.get_current_page()
     self.textview_list[id_page].replace_tabs() 
-        
+
   ###############################################################################
   # @brief Open recent menu call back
   ###############################################################################
@@ -1000,7 +1001,7 @@ class pygtkeditor_window(hildon.Window):
     dialog.set_logo_icon_name("pygtkeditor")
     dialog.set_authors(("Benoit HERVIER\n aka Khertan","","Thanks to :","Alterego for his help","Damien Moore for his patch"))
     dialog.set_comments('A source code editor for Maemo')
-    dialog.set_version("2.4.2")
+    dialog.set_version("2.4.4")
     dialog.set_license("This program is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.")
     dialog.set_copyright("By Benoit HERVIER (aka Khertan)")
     dialog.set_website("http://khertan.net/")
